<?php
namespace Jet_Engine\Modules\Profile_Builder;

class Forms_Integration {

	/**
	 * Constructor for the class
	 */
	public function __construct() {
		add_filter( 'jet-engine/forms/insert-post/pre-check', array( $this, 'check_posts_limit' ), 10, 4 );
	}

	/**
	 * Check posts limit
	 */
	public function check_posts_limit( $res, $postarr, $args, $notifications ) {

		// Apply restrictions only for post inserting, not the update
		if ( ! empty( $postarr['ID'] ) ) {
			return $res;
		}

		$restrictions = Module::instance()->settings->get( 'posts_restrictions' );

		if ( empty( $restrictions ) ){
			return $res;
		}

		$found_restriction = false;

		if ( ! is_user_logged_in() ) {
			$role = 'jet-engine-guest';
		} else {
			$user  = wp_get_current_user();
			$roles = array_values( $user->roles );
			$role  = $roles[0];
		}

		$found_restrictions = array();
		$post_type          = $postarr['post_type'];
		$find_by_post_type  = false;

		foreach ( $restrictions as $restriction ) {
			if ( ! empty( $restriction['role'] ) && in_array( $role, $restriction['role'] ) ) {
				$_post_type = ! empty( $restriction['post_type'] ) ? $restriction['post_type'] : 'all';

				if ( is_array( $_post_type ) ) {
					foreach ( $_post_type as $_p_type ) {
						$found_restrictions[ $_p_type ] = $restriction;
					}
				} else {
					$found_restrictions[ $_post_type ] = $restriction;
				}
			}
		}

		if ( isset( $found_restrictions[ $post_type ] ) ) {
			$found_restriction = $found_restrictions[ $post_type ];
			$find_by_post_type = $post_type;
		} else if ( isset( $found_restrictions['all'] ) ) {
			$found_restriction = $found_restrictions['all'];
		}

		$limit = ! empty( $found_restriction['limit'] ) ? absint( $found_restriction['limit'] ) : 0;

		if ( ! $limit ) {
			return $res;
		}

		$user_id    = isset( $user ) ? $user->ID : 0;
		$user_posts = $this->get_user_posts( $user_id, $find_by_post_type );

		if ( $user_posts >= $limit ) {
			$message = ! empty( $found_restriction['error_message'] ) ? $found_restriction['error_message'] : __( 'Posts limit reached', 'jet-engine' );
			$notifications->set_specific_status( $message );
			$res = false;
		}

		return $res;

	}

	/**
	 * Get user posts count
	 */
	public function get_user_posts( $user_id, $post_type = null ) {

		global $wpdb;

		$posts = $wpdb->posts;
		$user_id = absint( $user_id );

		$post_type_query = ! empty( $post_type ) ? "post_type = '$post_type' AND" : '';

		$query = sprintf( "SELECT COUNT(*) FROM $posts WHERE post_author = $user_id AND %s post_status IN ( 'draft', 'publish', 'trash' );", $post_type_query );

		$posts_num = $wpdb->get_var( $query );

		return absint( $posts_num );

	}

}
