import Filter from 'bases/Filter';

export default class SelectControl extends Filter {
	constructor($container, $filter, $select) {
		super($filter, $container);

		this.$select = $select || $filter.find('select');

		this.processData();
		this.initEvent();

		// reset the select when returning to the page
		this.resetSelectOnInitialization();
	}

	addFilterChangeEvent() {
		this.$select.on('change', () => {
			this.processData();
			this.emitFiterChange();
		})
	}

	removeChangeEvent() {
		this.$select.off();
	}

	processData() {
		this.dataValue = this.$selected.val();
	}

	setData(newData) {
		const $item = this.getItemByValue(newData);

		if ($item) {
			$item.prop(this.isSelect ? 'selected' : 'checked', true);
			this.processData();
		}
	}

	reset() {
		this.dataValue = false;
		this.$selected.prop(this.isSelect ? 'selected' : 'checked', false);
	}

	resetSelectOnInitialization() {
		if (!this.isSelect)
			return;

		$(document).ready(function () {
			if (this.filterGroup && this.filterGroup.currentQuery && this.filterGroup.currentQuery[this.queryKey])
				return;

			setTimeout(() => {
				this.$select.prop('selectedIndex', 0);
			});
		}.bind(this));
	}

	get activeValue() {
		const $item = this.getItemByValue(this.data);

		if ($item)
			return $item.data('label');
	}

	get $selected() {
		return this.isSelect ?
			this.$select.find(':checked') :
			this.$select.filter(':checked');
	}

	get isSelect() {
		return this.$select.prop('tagName') === 'SELECT' ? true : false;
	}

	// Additional methods
	getItemByValue(value) {
		let $item = false;

		if (this.isSelect) {
			this.$select.find('option').each((index, item) => {
				const $option = $(item);

				if ($option.val() === value)
					$item = $option
			});
		} else {
			$item = this.$select.filter('[value="' + value + '"]');
		}

		return $item;
	}
}